"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWebAddressesRows = void 0;
var primeobjects_helper_util_1 = require("primeobjects-helper-util");
var lodash_1 = require("lodash");
var getWebAddressesRows = function (props) {
    var _a, _b;
    var sectionLine = props.sectionLine, solution = props.solution, organization = props.organization, record = props.record, path = props.path, fieldNameForAPIName = props.fieldNameForAPIName, fieldLabelForNameBasedEndpoint = props.fieldLabelForNameBasedEndpoint, hideSection = props.hideSection;
    if (!(0, primeobjects_helper_util_1.isNonEmptyString)(record.shortId))
        record.shortId = (0, primeobjects_helper_util_1.newShortId)();
    var orgHasItsOwnSubDomain = (0, primeobjects_helper_util_1.isNonEmptyString)(organization.subdomain);
    var subdomain = orgHasItsOwnSubDomain
        ? organization.subdomain
        : organization.slug;
    var orgURL = "https://".concat(subdomain, ".").concat(solution.domain, "/");
    var apiNameFieldHasValue = !(0, lodash_1.isNil)(fieldNameForAPIName) &&
        (0, primeobjects_helper_util_1.isNonEmptyString)(record[fieldNameForAPIName]);
    var webSlug = apiNameFieldHasValue
        ? (0, primeobjects_helper_util_1.slug)(record[fieldNameForAPIName])
        : (0, primeobjects_helper_util_1.getRecordSlug)(record);
    var nameBasedAPIEndpoint = (_a = props.nameBasedAPIEndpoint) !== null && _a !== void 0 ? _a : "".concat(orgURL).concat(path, "/").concat(webSlug);
    var canonicalBasedAPIEndpoint = (_b = props.canonicalBasedAPIEndpoint) !== null && _b !== void 0 ? _b : "".concat(orgURL).concat(path, "/").concat(record.shortId);
    return [
        !hideSection && {
            fields: [
                {
                    wrapperStyle: {
                        marginBottom: 0
                    },
                    name: "webAddressSection",
                    type: "section",
                    line: sectionLine !== null && sectionLine !== void 0 ? sectionLine : "Web addresses and endpoints"
                }
            ]
        },
        (0, primeobjects_helper_util_1.isNonEmptyString)(nameBasedAPIEndpoint) && {
            fields: [
                {
                    name: "nameBasedAPIEndpoint",
                    label: "Name-based web address",
                    value: nameBasedAPIEndpoint,
                    useFieldValue: true,
                    format: "url",
                    type: "single-line-input",
                    alwaysShowLabel: true,
                    disabled: true,
                    note: apiNameFieldHasValue
                        ? "This URL will change while the ".concat(fieldLabelForNameBasedEndpoint !== null && fieldLabelForNameBasedEndpoint !== void 0 ? fieldLabelForNameBasedEndpoint : "name", " is changed.")
                        : "Although this URL will change while the ".concat(fieldLabelForNameBasedEndpoint !== null && fieldLabelForNameBasedEndpoint !== void 0 ? fieldLabelForNameBasedEndpoint : "name", " is changed , all previous URLs will always work.")
                }
            ]
        },
        (0, primeobjects_helper_util_1.isNonEmptyString)(canonicalBasedAPIEndpoint) && {
            fields: [
                {
                    name: "canonicalAPIEndpoint",
                    label: "Canonical web address",
                    value: canonicalBasedAPIEndpoint,
                    useFieldValue: true,
                    format: "url",
                    type: "single-line-input",
                    alwaysShowLabel: true,
                    disabled: true,
                    note: "This URL will never change."
                }
            ]
        }
    ];
};
exports.getWebAddressesRows = getWebAddressesRows;
//# sourceMappingURL=web-addresses-rows.js.map