import { getRecordSlug, slug, isNonEmptyString, newShortId } from "primeobjects-helper-util";
import { isNil } from "lodash";
export var getWebAddressesRows = function (props) {
    var _a, _b;
    var sectionLine = props.sectionLine, solution = props.solution, organization = props.organization, record = props.record, path = props.path, fieldNameForAPIName = props.fieldNameForAPIName, fieldLabelForNameBasedEndpoint = props.fieldLabelForNameBasedEndpoint, hideSection = props.hideSection;
    if (!isNonEmptyString(record.shortId))
        record.shortId = newShortId();
    var orgHasItsOwnSubDomain = isNonEmptyString(organization.subdomain);
    var subdomain = orgHasItsOwnSubDomain
        ? organization.subdomain
        : organization.slug;
    var orgURL = "https://".concat(subdomain, ".").concat(solution.domain, "/");
    var apiNameFieldHasValue = !isNil(fieldNameForAPIName) &&
        isNonEmptyString(record[fieldNameForAPIName]);
    var webSlug = apiNameFieldHasValue
        ? slug(record[fieldNameForAPIName])
        : getRecordSlug(record);
    var nameBasedAPIEndpoint = (_a = props.nameBasedAPIEndpoint) !== null && _a !== void 0 ? _a : "".concat(orgURL).concat(path, "/").concat(webSlug);
    var canonicalBasedAPIEndpoint = (_b = props.canonicalBasedAPIEndpoint) !== null && _b !== void 0 ? _b : "".concat(orgURL).concat(path, "/").concat(record.shortId);
    return [
        !hideSection && {
            fields: [
                {
                    wrapperStyle: {
                        marginBottom: 0
                    },
                    name: "webAddressSection",
                    type: "section",
                    line: sectionLine !== null && sectionLine !== void 0 ? sectionLine : "Web addresses and endpoints"
                }
            ]
        },
        isNonEmptyString(nameBasedAPIEndpoint) && {
            fields: [
                {
                    name: "nameBasedAPIEndpoint",
                    label: "Name-based web address",
                    value: nameBasedAPIEndpoint,
                    useFieldValue: true,
                    format: "url",
                    type: "single-line-input",
                    alwaysShowLabel: true,
                    disabled: true,
                    note: apiNameFieldHasValue
                        ? "This URL will change while the ".concat(fieldLabelForNameBasedEndpoint !== null && fieldLabelForNameBasedEndpoint !== void 0 ? fieldLabelForNameBasedEndpoint : "name", " is changed.")
                        : "Although this URL will change while the ".concat(fieldLabelForNameBasedEndpoint !== null && fieldLabelForNameBasedEndpoint !== void 0 ? fieldLabelForNameBasedEndpoint : "name", " is changed , all previous URLs will always work.")
                }
            ]
        },
        isNonEmptyString(canonicalBasedAPIEndpoint) && {
            fields: [
                {
                    name: "canonicalAPIEndpoint",
                    label: "Canonical web address",
                    value: canonicalBasedAPIEndpoint,
                    useFieldValue: true,
                    format: "url",
                    type: "single-line-input",
                    alwaysShowLabel: true,
                    disabled: true,
                    note: "This URL will never change."
                }
            ]
        }
    ];
};
//# sourceMappingURL=web-addresses-rows.js.map